/* -----------------------------------------------------------------------
   See COPYRIGHT.TXT and LICENSE.TXT for copyright and license information
   ----------------------------------------------------------------------- */
#ifndef _pcmd_compare_h_
#define _pcmd_compare_h_

#include "plmcli_config.h"
#include <string.h>
#include <stdlib.h>

void do_command_compare (int argc, char *argv[]);

#endif
